/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.rabbitmq;

import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;

import com.rabbitmq.client.ConnectionFactory;

public class RabbitMQConnectionFactorySupport {
    
    public ConnectionFactory createFactoryFor(final RabbitMQEndpoint endpoint) {
        ConnectionFactory factory = new ConnectionFactory();
        factory.setUsername(endpoint.getUsername());
        factory.setPassword(endpoint.getPassword());
        factory.setVirtualHost(endpoint.getVhost());
        factory.setHost(endpoint.getHostname());
        factory.setPort(endpoint.getPortNumber());
        if (endpoint.getClientProperties() != null) {
            factory.setClientProperties(endpoint.getClientProperties());
        }
        factory.setConnectionTimeout(endpoint.getConnectionTimeout());
        factory.setRequestedChannelMax(endpoint.getRequestedChannelMax());
        factory.setRequestedFrameMax(endpoint.getRequestedFrameMax());
        factory.setRequestedHeartbeat(endpoint.getRequestedHeartbeat());
        if (endpoint.getSslProtocol() != null) {
            try {
                if (endpoint.getSslProtocol().equals("true")) {
                    factory.useSslProtocol();
                } else if (endpoint.getTrustManager() == null) {
                    factory.useSslProtocol(endpoint.getSslProtocol());
                } else {
                    factory.useSslProtocol(endpoint.getSslProtocol(), endpoint.getTrustManager());
                }
            } catch (NoSuchAlgorithmException | KeyManagementException e) {
                throw new IllegalArgumentException("Invalid sslProtocol " + endpoint.getSslProtocol(), e);
            }
        }
        if (endpoint.getAutomaticRecoveryEnabled() != null) {
            factory.setAutomaticRecoveryEnabled(endpoint.getAutomaticRecoveryEnabled());
        }
        if (endpoint.getNetworkRecoveryInterval() != null) {
            factory.setNetworkRecoveryInterval(endpoint.getNetworkRecoveryInterval());
        }
        if (endpoint.getTopologyRecoveryEnabled() != null) {
            factory.setTopologyRecoveryEnabled(endpoint.getTopologyRecoveryEnabled());
        }
        return factory;
    }
}
